"use strict";
/**
 * @fileoverview Pass a context object when invoking a play function
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const context_in_play_function_1 = __importDefault(require("../../../lib/rules/context-in-play-function"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('context-in-play-function', context_in_play_function_1.default, {
    valid: [
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async (context) => {
          await FirstStory.play(context)
        }
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async ({ ...context }) => {
          await FirstStory.play({ ...context })
        }
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async ({ canvasElement, ...context }) => {
          await FirstStory.play({ canvasElement, ...context })
        }
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = Template.bind({})
      SecondStory.play = async (ctx) => {
        await FirstStory.play(ctx)
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = Template.bind({})
      SecondStory.play = async ({ canvasElement, ...ctx }) => {
        await FirstStory.play({ canvasElement, ...ctx })
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async (ctx) => {
          await FirstStory.play(ctx)
        }
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async ({ ...ctx }) => {
          await FirstStory.play({ ...ctx })
        }
      }
    `,
        (0, ts_dedent_1.default) `
      export const SecondStory = {
        play: async ({ canvasElement, ...ctx }) => {
          await FirstStory.play({ canvasElement, ...ctx })
        }
      }
    `,
    ],
    invalid: [
        {
            code: (0, ts_dedent_1.default) `
        export const SecondStory = {
          play: async ({ canvasElement }) => {
            await FirstStory.play({ canvasElement })
          }
        }
      `,
            errors: [
                {
                    messageId: 'passContextToPlayFunction',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const SecondStory = {
          play: async () => {
            await FirstStory.play()
          }
        }
      `,
            errors: [
                {
                    messageId: 'passContextToPlayFunction',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const SecondStory = Template.bind({})
        SecondStory.play = async ({ canvasElement }) => {
          await FirstStory.play({ canvasElement })
        }
      `,
            errors: [
                {
                    messageId: 'passContextToPlayFunction',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const SecondStory = Template.bind({})
        SecondStory.play = async () => {
          await FirstStory.play()
        }
      `,
            errors: [
                {
                    messageId: 'passContextToPlayFunction',
                },
            ],
        },
    ],
});
