"use strict";
/**
 * @fileoverview Component property should be set
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const csf_component_1 = __importDefault(require("../../../lib/rules/csf-component"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('csf-component', csf_component_1.default, {
    valid: [
        "export default { title: 'Button', component: Button }",
        "export default { title: 'Button', component: Button } as ComponentMeta<typeof Button>",
    ],
    invalid: [
        {
            code: "export default { title: 'Button' }",
            errors: [
                {
                    messageId: 'missingComponentProperty',
                    type: utils_1.AST_NODE_TYPES.ExportDefaultDeclaration,
                },
            ],
        },
        {
            code: "export default { title: 'Button' } as ComponentMeta<typeof Button>",
            errors: [
                {
                    messageId: 'missingComponentProperty',
                    type: utils_1.AST_NODE_TYPES.ExportDefaultDeclaration,
                },
            ],
        },
        {
            code: `
        const meta = { title: 'Button' } as Meta<typeof Button>
        export default meta
      `,
            errors: [
                {
                    messageId: 'missingComponentProperty',
                    type: utils_1.AST_NODE_TYPES.ExportDefaultDeclaration,
                },
            ],
        },
    ],
});
