"use strict";
/**
 * @fileoverview Story files should have a default export
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const default_exports_1 = __importDefault(require("../../../lib/rules/default-exports"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('default-exports', default_exports_1.default, {
    valid: [
        'export default { }',
        "export default { title: 'Button', component: Button }",
        "export default { title: 'Button', component: Button } as ComponentMeta<typeof Button>",
        `
      const meta = { title: 'Button', component: Button }
      export default meta
    `,
        `
      const meta: ComponentMeta<typeof Button> = { title: 'Button', component: Button }
      export default meta
    `,
        `
      import { storiesOf } from '@storybook/react'
      storiesOf('Component', module)
    `,
    ],
    invalid: [
        {
            code: 'export const Primary = () => <button>hello</button>',
            output: (0, ts_dedent_1.default) `
        export default {}
        export const Primary = () => <button>hello</button>
      `,
            errors: [
                {
                    messageId: 'shouldHaveDefaultExport',
                    suggestions: [
                        {
                            messageId: 'fixSuggestion',
                            output: 'export default {}\nexport const Primary = () => <button>hello</button>',
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        import { MyComponent, Foo } from './MyComponent'
        export const Primary = () => <button>hello</button>
      `,
            output: (0, ts_dedent_1.default) `
        import { MyComponent, Foo } from './MyComponent'
        export default { component: MyComponent }
        export const Primary = () => <button>hello</button>
      `,
            errors: [
                {
                    messageId: 'shouldHaveDefaultExport',
                    suggestions: [
                        {
                            messageId: 'fixSuggestion',
                            output: "import { MyComponent, Foo } from './MyComponent'\nexport default { component: MyComponent }\nexport const Primary = () => <button>hello</button>",
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        import MyComponent from './MyComponent'
        export const Primary = () => <button>hello</button>
      `,
            output: (0, ts_dedent_1.default) `
        import MyComponent from './MyComponent'
        export default { component: MyComponent }
        export const Primary = () => <button>hello</button>
      `,
            errors: [
                {
                    messageId: 'shouldHaveDefaultExport',
                    suggestions: [
                        {
                            messageId: 'fixSuggestion',
                            output: "import MyComponent from './MyComponent'\nexport default { component: MyComponent }\nexport const Primary = () => <button>hello</button>",
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        import { MyComponentProps } from './MyComponent'
        export const Primary = () => <button>hello</button>
      `,
            output: (0, ts_dedent_1.default) `
        import { MyComponentProps } from './MyComponent'
        export default {}
        export const Primary = () => <button>hello</button>
      `,
            errors: [
                {
                    messageId: 'shouldHaveDefaultExport',
                    suggestions: [
                        {
                            messageId: 'fixSuggestion',
                            output: "import { MyComponentProps } from './MyComponent'\nexport default {}\nexport const Primary = () => <button>hello</button>",
                        },
                    ],
                },
            ],
        },
    ],
});
