"use strict";
/**
 * @fileoverview Deprecated hierarchy separator
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const hierarchy_separator_1 = __importDefault(require("../../../lib/rules/hierarchy-separator"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('hierarchy-separator', hierarchy_separator_1.default, {
    valid: [
        'export default {  }',
        "export default { title: 'Examples.Components' }",
        "export default { title: 'Examples/Components/Button' }",
        "export default { title: 'Examples/Components/Button' } as ComponentMeta<typeof Button>",
        "export default { title: 'Examples.Components' } satisfies Meta<typeof Button>",
        'export default { ...props } as ComponentMeta<typeof Button>',
    ],
    invalid: [
        {
            code: "export default { title: 'Examples|Components/Button' }",
            output: "export default { title: 'Examples/Components/Button' }",
            errors: [
                {
                    type: utils_1.AST_NODE_TYPES.Property,
                    messageId: 'deprecatedHierarchySeparator',
                    suggestions: [
                        {
                            messageId: 'useCorrectSeparators',
                            output: "export default { title: 'Examples/Components/Button' }",
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const meta = { title: 'Examples|Components/Button' }
        export default meta
      `,
            output: (0, ts_dedent_1.default) `
        const meta = { title: 'Examples/Components/Button' }
        export default meta
      `,
            errors: [
                {
                    type: utils_1.AST_NODE_TYPES.Property,
                    messageId: 'deprecatedHierarchySeparator',
                    suggestions: [
                        {
                            messageId: 'useCorrectSeparators',
                            output: (0, ts_dedent_1.default) `
                const meta = { title: 'Examples/Components/Button' }
                export default meta
              `,
                        },
                    ],
                },
            ],
        },
    ],
});
