"use strict";
/**
 * @fileoverview Meta should have inline properties
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const meta_inline_properties_1 = __importDefault(require("../../../lib/rules/meta-inline-properties"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('meta-inline-properties', meta_inline_properties_1.default, {
    valid: [
        "export default { title: 'Button', args: { primary: true } }",
        "export default { title: 'Button', args: { primary: true } } as ComponentMeta<typeof Button>",
    ],
    invalid: [
        {
            code: `
      const title = 'foo';
      const args = { a: 1 };
      export default { title, args };
    `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'args',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
        {
            code: `
        export default { title: 'a' + 123 };
      `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
        {
            code: `
        export default { title: \`a \${123}\` };
      `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
        {
            code: `
        const title = 'a'

        export default {
          title,
          component: Badge,
        } as ComponentMeta<typeof Badge>
      `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
        {
            code: `
        export default {
          title: someFunction(),
        }
      `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const title = 'a'

        const meta: ComponentMeta<typeof Badge> = {
          title,
          component: Badge,
        }

        export default meta
      `,
            errors: [
                {
                    messageId: 'metaShouldHaveInlineProperties',
                    data: {
                        property: 'title',
                    },
                    type: utils_1.AST_NODE_TYPES.Property,
                },
            ],
        },
    ],
});
