"use strict";
/**
 * @fileoverview Named exports should not use the name annotation if it is redundant to the name that would be generated by the export name
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const no_redundant_story_name_1 = __importDefault(require("../../../lib/rules/no-redundant-story-name"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('no-redundant-story-name', no_redundant_story_name_1.default, {
    valid: [
        "export const PrimaryButton = { name: 'The Primary Button' }",
        "export const PrimaryButton: Story = { name: 'The Primary Button' }",
        `
      const Default = {}
      export const PrimaryButton = { ...Default, name: 'The Primary Button' }
    `,
        `
      export const PrimaryButton = Template.bind({})
      PrimaryButton.storyName = 'The Primary Button'
    `,
        `
      export function PrimaryButton () {
        return <div>Hello</div>
      }
      PrimaryButton.storyName = 'The Primary Button'
    `,
        `
      export function H1 () {
        return <h1>Hello</h1>
      }
      H1.storyName = 'H1'
    `,
    ],
    invalid: [
        {
            code: "export const PrimaryButton = { name: 'Primary Button' }",
            errors: [
                {
                    messageId: 'storyNameIsRedundant',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeRedundantName',
                            output: 'export const PrimaryButton = {  }',
                        },
                    ],
                },
            ],
        },
        {
            code: "export const PrimaryButton: Story = { name: 'Primary Button' }",
            errors: [
                {
                    messageId: 'storyNameIsRedundant',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeRedundantName',
                            output: 'export const PrimaryButton: Story = {  }',
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const PrimaryButton = Template.bind({})
        PrimaryButton.storyName = 'Primary Button'
      `,
            errors: [
                {
                    messageId: 'storyNameIsRedundant',
                    type: utils_1.AST_NODE_TYPES.AssignmentExpression,
                    suggestions: [
                        {
                            messageId: 'removeRedundantName',
                            output: (0, ts_dedent_1.default) `
                export const PrimaryButton = Template.bind({})

              `,
                        },
                    ],
                },
            ],
        },
    ],
});
