"use strict";
/**
 * @fileoverview No title property in meta
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const no_title_property_in_meta_1 = __importDefault(require("../../../lib/rules/no-title-property-in-meta"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('no-title-property-in-meta', no_title_property_in_meta_1.default, {
    valid: [
        'export default {  }',
        'export default { component: Button }',
        'export default { component: Button } as ComponentMeta<typeof Button>',
        'export default { component: Button } as Meta<typeof Button>',
        'export default { component: Button } satisfies Meta<typeof Button>',
        'export default { ...props }',
    ],
    invalid: [
        {
            code: "export default { title: 'Button', component: Button }",
            errors: [
                {
                    messageId: 'noTitleInMeta',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeTitleInMeta',
                            output: 'export default {  component: Button }',
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const meta = { component: Button, title: 'Button' }
        export default meta
      `,
            errors: [
                {
                    messageId: 'noTitleInMeta',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeTitleInMeta',
                            output: (0, ts_dedent_1.default) `
                const meta = { component: Button,  }
                export default meta
              `,
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const meta = { component: Button, title: 'Button' } as Meta<typeof Button>
        export default meta
      `,
            errors: [
                {
                    messageId: 'noTitleInMeta',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeTitleInMeta',
                            output: (0, ts_dedent_1.default) `
                const meta = { component: Button,  } as Meta<typeof Button>
                export default meta
              `,
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const meta = { component: Button, title: 'Button' } satisfies Meta<typeof Button>
        export default meta
      `,
            errors: [
                {
                    messageId: 'noTitleInMeta',
                    type: utils_1.AST_NODE_TYPES.Property,
                    suggestions: [
                        {
                            messageId: 'removeTitleInMeta',
                            output: (0, ts_dedent_1.default) `
                const meta = { component: Button,  } satisfies Meta<typeof Button>
                export default meta
              `,
                        },
                    ],
                },
            ],
        },
    ],
});
