"use strict";
/**
 * @fileoverview Prefer pascal case
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const prefer_pascal_case_1 = __importDefault(require("../../../lib/rules/prefer-pascal-case"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('prefer-pascal-case', prefer_pascal_case_1.default, {
    valid: [
        'export const Primary = {}',
        `export const __namedExportsOrder = ['Secondary', 'Primary']`,
        `export const _primary = {}`,
        'export const Primary: Story = {}',
        `
      import { storiesOf } from '@storybook/react'
      export const links = []
      storiesOf('Component', module)
    `,
        `
      export default {
        title: 'MyComponent',
        component: MyComponent,
        includeStories: ['SimpleStory', 'ComplexStory'],
        excludeStories: /.*Data$/,
      };

      export const simpleData = { foo: 1, bar: 'baz' };
      export const complexData = { foo: 1, foobar: { bar: 'baz', baz: someData } };

      export const SimpleStory = () => <MyComponent data={simpleData} />;
      export const ComplexStory = () => <MyComponent data={complexData} />;
    `,
        `
      export default {
        title: 'MyComponent',
        component: MyComponent,
        includeStories: [MyComponent.name],
      };

      export const SimpleStory = () => <MyComponent />;
    `,
    ],
    invalid: [
        {
            code: (0, ts_dedent_1.default) `
        export const primary = {}
        primary.foo = 'bar'
      `,
            errors: [
                {
                    messageId: 'usePascalCase',
                    data: {
                        name: 'primary',
                    },
                    type: utils_1.AST_NODE_TYPES.Identifier,
                    suggestions: [
                        {
                            messageId: 'convertToPascalCase',
                            output: (0, ts_dedent_1.default) `
                export const Primary = {}
                Primary.foo = 'bar'
              `,
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const primary: Story = {}
        primary.foo = 'bar'
      `,
            errors: [
                {
                    messageId: 'usePascalCase',
                    data: {
                        name: 'primary',
                    },
                    type: utils_1.AST_NODE_TYPES.Identifier,
                    suggestions: [
                        {
                            messageId: 'convertToPascalCase',
                            output: (0, ts_dedent_1.default) `
                export const Primary: Story = {}
                Primary.foo = 'bar'
              `,
                        },
                    ],
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export default {
          title: 'MyComponent',
          component: MyComponent,
          includeStories: /.*Story$/,
          excludeStories: /.*Data$/,
        };
        export const simpleData = { foo: 1, bar: 'baz' };
        export const complexData = { foo: 1, foobar: { bar: 'baz', baz: someData } };
        export const simpleStory = () => <MyComponent data={simpleData} />;
        simpleStory.args = {};
      `,
            errors: [
                {
                    messageId: 'usePascalCase',
                    data: {
                        name: 'simpleStory',
                    },
                    type: utils_1.AST_NODE_TYPES.Identifier,
                    suggestions: [
                        {
                            messageId: 'convertToPascalCase',
                            output: (0, ts_dedent_1.default) `
                export default {
                  title: 'MyComponent',
                  component: MyComponent,
                  includeStories: /.*Story$/,
                  excludeStories: /.*Data$/,
                };
                export const simpleData = { foo: 1, bar: 'baz' };
                export const complexData = { foo: 1, foobar: { bar: 'baz', baz: someData } };
                export const SimpleStory = () => <MyComponent data={simpleData} />;
                SimpleStory.args = {};
              `,
                        },
                    ],
                },
            ],
        },
    ],
});
