"use strict";
/**
 * @fileoverview A story file must contain at least one story export
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const story_exports_1 = __importDefault(require("../../../lib/rules/story-exports"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('story-exports', story_exports_1.default, {
    valid: [
        'export const Primary = {}',
        (0, ts_dedent_1.default) `
      export default {}
      export const Primary = {}
    `,
        (0, ts_dedent_1.default) `
      export default {} as ComponentMeta<typeof RestaurantDetailPage>
      export const Primary = {}
    `,
        (0, ts_dedent_1.default) `
      import { storiesOf } from '@storybook/react'
      storiesOf('MyComponent', module)
    `,
        (0, ts_dedent_1.default) `
      const Primary = {}
      const Secondary = {}
      export default {}
      export { Primary, Secondary }
    `,
        `
      export default {
        title: 'MyComponent',
        component: MyComponent,
        includeStories: [MyComponent.name],
      };

      export const SimpleStory = () => <MyComponent />;
    `,
        (0, ts_dedent_1.default) `
      export default {
        excludeStories: /.*Data$/,
      }

      const mockData = {}
      const Primary = {}

      export { mockData, Primary }
    `,
        'export function Primary() {}',
        (0, ts_dedent_1.default) `
      export default {}
      export function Primary() {}
    `,
        (0, ts_dedent_1.default) `
      export default {} as ComponentMeta<typeof RestaurantDetailPage>
      export function Primary() {}
    `,
    ],
    invalid: [
        {
            code: (0, ts_dedent_1.default) `
        export default {
          component: Button
        } as ComponentMeta<typeof RestaurantDetailPage>`,
            // output: dedent`
            //   export default {
            //     component: Button
            //   } as ComponentMeta<typeof RestaurantDetailPage>
            //   export const Default = {}
            // `,
            errors: [
                {
                    messageId: 'shouldHaveStoryExport',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export default {
          excludeStories: /.*Data$/,
        }

        export const mockData = {}
      `,
            // output: dedent`
            //   export default {
            //     excludeStories: /.*Data$/,
            //   }
            //   export const mockData = {}
            //   export const Default = {}
            // `,
            errors: [
                {
                    messageId: 'shouldHaveStoryExportWithFilters',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export default {
          excludeStories: /.*Data$/,
        }

        const mockData = {}
        const Primary = {}

        export { mockData }
      `,
            // output: dedent`
            //   export default {
            //     excludeStories: /.*Data$/,
            //   }
            //   const mockData = {}
            //   const Primary = {}
            //   export { mockData }
            //   export const Default = {}
            // `,
            errors: [
                {
                    messageId: 'shouldHaveStoryExportWithFilters',
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export default {
          excludeStories: /.*Data$/,
        }

        export function generateMockData() {}
      `,
            // output: dedent`
            //   export default {
            //     excludeStories: /.*Data$/,
            //   }
            //   export function generateMockData() {}
            //   export const Default = {}
            // `,
            errors: [
                {
                    messageId: 'shouldHaveStoryExportWithFilters',
                },
            ],
        },
    ],
});
