"use strict";
/**
 * @fileoverview Use expect from &#39;@storybook/jest&#39;
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const ts_dedent_1 = __importDefault(require("ts-dedent"));
const use_storybook_expect_1 = __importDefault(require("../../../lib/rules/use-storybook-expect"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('use-storybook-expect', use_storybook_expect_1.default, {
    valid: [
        (0, ts_dedent_1.default) `
      import { expect } from '@storybook/jest';

      Default.play = () => {
        expect(123).toEqual(123);
      }
    `,
        (0, ts_dedent_1.default) `
      import { expect } from '@storybook/jest';

      export const Basic = {
        ...Default,
        play: async (context) => {
          expect(123).toEqual(123);
        },
      };
    `,
        (0, ts_dedent_1.default) `
      import { expect } from '@storybook/test';

      Default.play = () => {
        expect(123).toEqual(123);
      }
    `,
        (0, ts_dedent_1.default) `
      import { expect } from '@storybook/test';

      export const Basic = {
        ...Default,
        play: async (context) => {
          expect(123).toEqual(123);
        },
      };
    `,
    ],
    invalid: [
        {
            code: (0, ts_dedent_1.default) `
        Default.play = () => {
          expect(123).toEqual(123);
        }
      `,
            errors: [
                {
                    messageId: 'useExpectFromStorybook',
                    type: utils_1.AST_NODE_TYPES.Identifier,
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        const someInteraction = () => {
          expect(123).toEqual(123);
        }
        Default.play = someInteraction
      `,
            errors: [
                {
                    messageId: 'useExpectFromStorybook',
                    type: utils_1.AST_NODE_TYPES.Identifier,
                },
            ],
        },
        {
            code: (0, ts_dedent_1.default) `
        export const Basic = {
          ...Default,
          play: async (context) => {
            expect(123).toEqual(123);
          },
        };
      `,
            errors: [
                {
                    messageId: 'useExpectFromStorybook',
                    type: utils_1.AST_NODE_TYPES.Identifier,
                },
            ],
        },
    ],
});
