"use strict";
/**
 * @fileoverview Do not testing library directly on stories
 * @author Yann Braga
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------
const utils_1 = require("@typescript-eslint/utils");
const use_storybook_testing_library_1 = __importDefault(require("../../../lib/rules/use-storybook-testing-library"));
const rule_tester_1 = __importDefault(require("../../utils/rule-tester"));
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------
rule_tester_1.default.run('use-storybook-testing-library', use_storybook_testing_library_1.default, {
    valid: ["import { within } from '@storybook/testing-library'"],
    invalid: [
        {
            code: "import { within } from '@testing-library/dom'",
            output: "import { within } from '@storybook/testing-library'",
            errors: [
                {
                    messageId: 'dontUseTestingLibraryDirectly',
                    data: {
                        library: '@testing-library/dom',
                    },
                    type: utils_1.AST_NODE_TYPES.ImportDeclaration,
                    suggestions: [
                        {
                            messageId: 'updateImports',
                            output: "import { within } from '@storybook/testing-library'",
                        },
                    ],
                },
            ],
        },
        {
            code: "import userEvent from '@testing-library/user-event'",
            output: "import { userEvent } from '@storybook/testing-library'",
            errors: [
                {
                    messageId: 'dontUseTestingLibraryDirectly',
                    data: {
                        library: '@testing-library/user-event',
                    },
                    type: utils_1.AST_NODE_TYPES.ImportDeclaration,
                    suggestions: [
                        {
                            messageId: 'updateImports',
                            output: "import { userEvent } from '@storybook/testing-library'",
                        },
                    ],
                },
            ],
        },
        {
            code: "import userEvent, { foo, bar as Bar } from '@testing-library/user-event'",
            output: "import { userEvent, foo, bar as Bar } from '@storybook/testing-library'",
            errors: [
                {
                    messageId: 'dontUseTestingLibraryDirectly',
                    data: {
                        library: '@testing-library/user-event',
                    },
                    type: utils_1.AST_NODE_TYPES.ImportDeclaration,
                    suggestions: [
                        {
                            messageId: 'updateImports',
                            output: "import { userEvent, foo, bar as Bar } from '@storybook/testing-library'",
                        },
                    ],
                },
            ],
        },
    ],
});
